@@ -1,4 +1,4 @@
-`recode` <-
+recode <-
 function(vec,original,modified) {
 if (length(original) != length(modified)) stop("original & modofied lengths differ")
 rvec<-vector(mode=mode(vec),length=length(vec))
